# -*- coding: utf-8 -*-
from setuphelpers import *

bin_path = makepath("/","usr","bin","gcompris")
install_dir = makepath('/','opt', 'gcompris')
bashrc_global = "/etc/bash.bashrc"

def install():
    bin = glob.glob('gcompris*64.sh')[0]
    if not isdir(install_dir):
        mkdirs(install_dir)

    filecopyto(bin, install_dir)
    install_bin = makepath(install_dir, bin)
    run(f'chmod u+x {install_bin}')
    run(f'yes | {install_bin} --prefix={install_dir} --exclude-subdir')

    # Création de l'alias pour gcompris
    alias_command = f"export LD_LIBRARY_PATH={install_dir}/bin ; {install_dir}/bin/gcompris-qt"
    add_alias("gcompris", alias_command)

    if isdir(install_bin):
        remove_tree(install_bin)


def uninstall():
    remove_alias("gcompris")

    if isdir(install_dir):
        remove_tree(install_dir)


def add_alias(alias_name, command_name):
    alias_command = f"alias {alias_name}='{command_name}'\n"

    if not alias_exists(bashrc_global, alias_name):
        with open(bashrc_global, "a") as bashrc:
            bashrc.write(alias_command)
        # reload bashrc
        run(f'bash -c "source {bashrc_global}"')


def alias_exists(file_path, alias_name):
    with open(file_path, "r") as file:
        lines = file.readlines()
        for line in lines:
            if line.strip().startswith(f"alias {alias_name}="):
                return True
    return False


def remove_alias(alias_name):
    if alias_exists(bashrc_global, alias_name):
        run(f"sed -i '/alias {alias_name}=/d' {bashrc_global}")
        # Reload bashrc
        run(f'bash -c "source {bashrc_global}"')
